EventListener

Struct EventListener 

pub struct EventListener { /* private fields */ }
DOM event listener.

Implementations

Source

impl EventListener

pub fn listen<T, F>(target: T, event_type: &str, f: F) -> Self
where T: AsRef<EventTarget>, F: FnMut(Event) + Clone + 'static,

Register an event listener.

pub fn listen_once<T, F>(target: T, event_type: &str, f: F) -> Self
where T: AsRef<EventTarget>, F: FnOnce(Event) + 'static,

Register an event listener that will be called at most once.

pub fn forget(self)

Keeps the EventListener alive forever, so it will never be dropped.

This should only be used when you want the EventListener to last forever, otherwise it will leak memory.

pub fn target(&self) -> &EventTarget

Returns the EventTarget.

pub fn event_type(&self) -> &str

Returns the event type.

pub fn phase(&self) -> EventPhase

Returns whether the event listener is run during the capture or bubble phase.

The official specification has a good explanation of capturing vs bubbling.