pub struct Beacon { /* private fields */ }Expand description
Asynchronously send a small amount of data to an HTTP server.
This API is intended to send analytics and diagnostics data to a server before a document is unloaded.
See MDN - Navigator.sendBeacon for more.
Examples
ⓘ
document.on("unload", || {
let beacon = Beacon::new();
beacon.send_to("localhost:8080/log", b"client closed");
});Implementations